<?php
require_once 'otgs-fancybox-gallery-options-loader.class.php';

class OTGS_Fancybox_Gallery_Options {
	/**
	 * Defines defaults values for all plugin settings
	 * @var array
	 */
	protected static $default_settings = array(
			'enable_styles'      => false,
			'watermark_image'    => false,
			'watermark_position' => 'br',
			'watermark_padding'  => 0,
	);

	/**
	 * The name of the option name stored in wp_options
	 * @var string
	 */
	protected static $option_name = 'otgs-fg-settings';

	public function __construct() {
		OTGS_Fancybox_Gallery_Options_Loader::init();
	}

	public static function get_settings() {
		return get_option( self::$option_name, self::$default_settings );
	}

	/**
	 * Register all sections and fields using WP Settings API
	 */
	public function register_settings() {
		register_setting( 'otgs-fg-settings-group', 'otgs-fg-settings' );

		add_settings_section( 'options', 'Options', array( $this, 'section_options_callback' ), 'otgs_fancybox_gallery' );

		add_settings_field( 'enable_styles', 'Enable Styles', array( $this, 'enable_styles_callback' ), 'otgs_fancybox_gallery', 'options' );
		add_settings_field( 'watermark_image', 'Watermark', array( $this, 'watermark_image_callback' ), 'otgs_fancybox_gallery', 'options' );
		add_settings_field( 'watermark_position', 'Watermark Position', array( $this, 'watermark_position_callback' ), 'otgs_fancybox_gallery', 'options' );
		add_settings_field( 'watermark_padding', 'Watermark Padding', array( $this, 'watermark_padding_callback' ), 'otgs_fancybox_gallery', 'options' );
	}

	public function section_framework_callback() {
		echo '';
	}

	public function section_options_callback() {
		echo '';
	}

	public function enable_styles_callback() {
		$enable_styles = esc_attr( self::get_setting( 'enable_styles' ) );
		$checked       = checked( 1, $enable_styles, false );
		echo '<input type="checkbox" id="enable_styles" name="' . self::$option_name . '[enable_styles]" value="1"' . $checked . ' />';
	}

	public static function get_setting( $option_name ) {
		$settings = get_option( self::$option_name, self::$default_settings );

		if ( isset( $settings[ $option_name ] ) ) {
			return $settings[ $option_name ];
		} elseif ( isset( self::$default_settings[ $option_name ] ) ) {
			return self::$default_settings[ $option_name ];
		} else {
			return false;
		}
	}

	public function watermark_image_callback() {
		$watermark = esc_attr( self::get_setting( 'watermark_image' ) );
		echo '<figure class="watermark_preview">';
		echo '<img src="' . wp_get_attachment_url( $watermark ) . '" />';
		echo '</figure>';
		echo '<input type="hidden" id="watermark" name="' . self::$option_name . '[watermark_image]" value="' . $watermark . '" />';
		echo '<button type="button" id="watermark_selector" name="watermark_selector" class="otgs_fg_upload_image_button button button-secondary">';
		echo __( 'Select or upload an image', 'otgs_fg' );
		echo '</button>';
		echo '&nbsp;';
		echo '<button type="button" name="watermark_remove" value="' . $watermark . '" class="watermark_remove button button-secondary">';
		echo __( 'Remove image', 'otgs_fg' );
		echo '</button>';
		echo '&nbsp;';
		echo '<div class="watermark_updated_message updated below-h2">' . __( 'Please save to apply this change.', 'otgs_fg' ) . '</div>';
	}

	public function watermark_position_callback() {
		$watermark_image = esc_attr( self::get_setting( 'watermark_position' ) );

		$positions = array(
				'tl' => __( 'Top Left', 'otgs_fg' ),
				'tc' => __( 'Top Center', 'otgs_fg' ),
				'tr' => __( 'Top Right', 'otgs_fg' ),
				'bl' => __( 'Bottom Left', 'otgs_fg' ),
				'bc' => __( 'Bottom Center', 'otgs_fg' ),
				'br' => __( 'Bottom Right', 'otgs_fg' ),
		);

		$p = 0;

		echo '<div style="width:50%;">';
		foreach ( $positions as $position => $label ) {
			$p++;
			$checked = checked( $position, $watermark_image, false );
			echo '<label for="watermark_' . $position . '" style="width:33%; display:inline-block;">';
			echo '<input type="radio" id="watermark_' . $position . '" name="' . self::$option_name . '[watermark_position]" value="' . $position . '" ' . $checked . ' />';
			echo ' ' . $label . '</label>';
			if ( $p % 3 == 0 ) {
				echo '</div>';
				echo '<div style="width:50%;">';
			}
		}
		echo '</div>';
	}

	public function watermark_padding_callback() {
		$watermark_padding = esc_attr( self::get_setting( 'watermark_padding' ) );
		echo '<input type="number" id="watermark_padding" name="' . self::$option_name . '[watermark_padding]" value="' . $watermark_padding . '" />';
		echo __( '(pixels)', 'otgs_fg' );
	}

	/**
	 * Renders the option page, by calling WP Settings API functions
	 */
	public function options_do_page() {
		?>
		<div class="wrap">
			<h2><?php echo get_admin_page_title(); ?></h2>

			<h3><?php __( 'OTGS FancyBox Gallery', 'otgs_fg' ); ?></h3>

			<form action="options.php" method="POST">
				<?php
				settings_fields( 'otgs-fg-settings-group' );
				do_settings_sections( 'otgs_fancybox_gallery' );
				submit_button();
				?>
			</form>
		</div>
	<?php
	}

	public function admin_menu() {
		add_options_page( 'OTGS Fancybox Gallery', 'Fancybox Gallery', 'manage_options', 'otgs_fancybox_gallery', array( $this, 'options_do_page' ) );
	}

	public function admin_enqueue_scripts( $hook ) {
		if ( 'settings_page_otgs_fancybox_gallery' == $hook ) {
			wp_enqueue_media();
			wp_register_script( 'otgs_fg_options', OTGS_FG_URL . '/admin/res/js/options.js', array( 'jquery' ), true );
			wp_enqueue_script( 'otgs_fg_options' );
		}
	}
}

global $OTGS_Fancybox_Gallery_Options;
$OTGS_Fancybox_Gallery_Options = new OTGS_Fancybox_Gallery_Options();