<?php
require_once 'otgs-fancybox-gallery-loader.class.php';

class OTGS_Fancybox_Gallery {
	public function __construct() {
		OTGS_Fancybox_Gallery_Loader::init();
	}

function front_end_scripts() {
	global $OTGS_Fancybox_Gallery_Options;
	$enable_styles = $OTGS_Fancybox_Gallery_Options::get_setting( 'enable_styles' );

	if ( !is_admin() ) {
		//	CSS
		wp_register_style( 'otgs_fg_app', OTGS_FG_URL . '/res/css/app.css', array( 'fancybox' ) );
		//  CSS - Vendors
		wp_register_style( 'fancybox', '//cdnjs.cloudflare.com/ajax/libs/fancybox/2.1.5/jquery.fancybox.css', array() );
		wp_register_style( 'fancybox-buttons', '//cdnjs.cloudflare.com/ajax/libs/fancybox/2.1.5/helpers/jquery.fancybox-buttons.css', array( 'fancybox' ) );
		wp_register_style( 'fancybox-thumbs', '//cdnjs.cloudflare.com/ajax/libs/fancybox/2.1.5/helpers/jquery.fancybox-thumbs.css', array( 'fancybox' ) );

		//	JS
		wp_register_script( 'otgs_fg_gallery', OTGS_FG_URL . '/res/js/gallery.js', array( 'fancybox', 'mousewheel' ), true );
		//  JS - Vendors
		wp_register_script( 'mousewheel', '//cdnjs.cloudflare.com/ajax/libs/jquery-mousewheel/3.1.11/jquery.mousewheel.min.js', array( 'jquery' ), true );
		wp_register_script( 'fancybox-pack', '//cdnjs.cloudflare.com/ajax/libs/fancybox/2.1.5/jquery.fancybox.pack.js', array( 'fancybox' ), true );
		wp_register_script( 'fancybox', '//cdnjs.cloudflare.com/ajax/libs/fancybox/2.1.5/jquery.fancybox.min.js', array( 'jquery' ), true );
		//  JS - Vendors - Fancybox Helpers
		wp_register_script( 'fancybox-buttons', '//cdnjs.cloudflare.com/ajax/libs/fancybox/2.1.5/helpers/jquery.fancybox-buttons.js', array( 'fancybox-pack' ), true );
		wp_register_script( 'fancybox-media', '//cdnjs.cloudflare.com/ajax/libs/fancybox/2.1.5/helpers/jquery.fancybox-media.js', array( 'fancybox-pack' ), true );
		wp_register_script( 'fancybox-thumbs', '//cdnjs.cloudflare.com/ajax/libs/fancybox/2.1.5/helpers/jquery.fancybox-thumbs.js', array( 'fancybox-pack' ), true );
		wp_register_script( 'twitter-widgets', '//platform.twitter.com/widgets.js', array( 'fancybox-pack' ), true );

		// Queuing
		if ( $enable_styles ) {
			wp_enqueue_style( 'otgs_fg_app' );
		}
		$settings = $OTGS_Fancybox_Gallery_Options::get_settings();
		if ( isset( $settings[ 'watermark_image' ] ) ) {
			$settings[ 'watermark_url' ] = wp_get_attachment_url( $settings[ 'watermark_image' ] );
		}
		wp_localize_script( 'otgs_fg_gallery', 'settings', $settings );
		wp_enqueue_script( 'otgs_fg_gallery' );
	}
}

	/**
	 * Called by 'get_attachment_link' filter, when looping through gallery items
	 *
	 * @param $markup    string HTML string of the image
	 * @param $id        int
	 * @param $size      string|array
	 * @param $permalink string
	 * @param $icon      bool
	 * @param $text      string
	 *
	 * @return bool|string
	 */
	function get_attachment_link( $markup, $id, $size, $permalink, $icon, $text ) {
	$id    = intval( $id );
	$_post = get_post( $id );

	$cache_key   = md5( json_encode( array( $markup, $id, $size, $permalink, $icon, $text, $_post ) ) );
	$cache_group = 'get_attachment_link';
	$cache_found = false;

	$link = wp_cache_get( $cache_key, $cache_group, false, $cache_found );

	if ( $cache_found ) {
		return $link;
	}

	if ( empty( $_post ) || ( 'attachment' != $_post->post_type ) || !$url = wp_get_attachment_url( $_post->ID ) ) {
		return __( 'Missing Attachment' );
	}

	if ( $permalink ) {
		$img = wp_get_attachment_image_src( $id, 'full' );
		$url = $img[ 0 ];
	}
	$post_title = esc_attr( $_post->post_title );

	if ( $text ) {
		$link_text = $text;
	} elseif ( $size && 'none' != $size ) {
		$link_text = wp_get_attachment_image( $id, $size, $icon );
	} else {
		$link_text = '';
	}

	if ( trim( $link_text ) == '' ) {
		$link_text = $_post->post_title;
	}

	$classes = array(
			'fancybox',
			'fancy',
	);

	$link = "<a href=\"$url\" title=\"$post_title\" class=\"" . implode( ' ', $classes ) . "\" rel=\"group\">$link_text</a>";

	wp_cache_set( $cache_key, $link, $cache_group );

	return $link;
}
}

global $OTGS_Fancybox_Gallery;
$OTGS_Fancybox_Gallery = new OTGS_Fancybox_Gallery();